@@ -5,4 +5,4 @@
 # SPDX-License-Identifier: GPL-3.0-or-later
 
 # Extract for Qt Linguist
-$EXTRACT_TR_STRINGS `find src/ -name \*.cpp -o -name \*.h` -o $podir/ghostwriter_qt.pot
\ No newline at end of file
+$EXTRACT_TR_STRINGS `find src/ -name \*.cpp -o -name \*.h -o -name \*.ui` -o $podir/ghostwriter_qt.pot
